@@ -1,4 +1,4 @@
-predict.fishnet=function(object,newx,s=NULL,type=c("link","response","coefficients","nonzero"),exact=TRUE,offset,...){
+predict.fishnet=function(object,newx,s=NULL,type=c("link","response","coefficients","nonzero"),exact=FALSE,offset,...){
   type=match.arg(type)
 nfit=NextMethod("predict")
   switch(type,
